'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');

function _slicedToArray(arr, i) {
  return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest();
}

function _arrayWithHoles(arr) {
  if (Array.isArray(arr)) return arr;
}

function _iterableToArrayLimit(arr, i) {
  if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return;
  var _arr = [];
  var _n = true;
  var _d = false;
  var _e = undefined;

  try {
    for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
      _arr.push(_s.value);

      if (i && _arr.length === i) break;
    }
  } catch (err) {
    _d = true;
    _e = err;
  } finally {
    try {
      if (!_n && _i["return"] != null) _i["return"]();
    } finally {
      if (_d) throw _e;
    }
  }

  return _arr;
}

function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}

function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;

  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

  return arr2;
}

function _nonIterableRest() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

var I18nContext = React.createContext({});
var I18nProvider = function I18nProvider(props) {
  var children = props.children,
      initialLocale = props.initialLocale,
      translations = props.translations,
      onChange = props.onChange;

  var _useState = React.useState(initialLocale),
      _useState2 = _slicedToArray(_useState, 2),
      locale = _useState2[0],
      _setLocale = _useState2[1];

  var memoizedValue = React.useMemo(function () {
    return {
      locale: locale,
      translations: translations[locale],
      setLocale: function setLocale(newLocale) {
        _setLocale(newLocale);

        if (onChange) {
          onChange(locale, newLocale);
        }
      }
    };
  }, [locale]);
  return /*#__PURE__*/React.createElement(I18nContext.Provider, {
    value: memoizedValue
  }, children);
};

var replacePlaceholders = function replacePlaceholders(text, keyValuePairs) {
  return Object.entries(keyValuePairs).reduce(function (result, _ref) {
    var _ref2 = _slicedToArray(_ref, 2),
        key = _ref2[0],
        value = _ref2[1];

    return result.replace("{".concat(key, "}"), value);
  }, text);
};
var getT = function getT(translations, namespace) {
  return function (id, placeholderValues) {
    var translationId = id;
    var namespacedId = "".concat(namespace, ":").concat(id);

    if (namespace && translations[namespacedId]) {
      translationId = namespacedId;
    }

    var translation = translations[translationId];

    if (!translation) {
      return translationId;
    }

    return placeholderValues ? replacePlaceholders(translation, placeholderValues) : translation;
  };
};

var useTranslation = function useTranslation(namespace) {
  var _useContext = React.useContext(I18nContext),
      locale = _useContext.locale,
      translations = _useContext.translations,
      setLocale = _useContext.setLocale;

  var t = getT(translations, namespace);
  return {
    locale: locale,
    setLocale: setLocale,
    t: t
  };
};

var Translation = function Translation(_ref) {
  var id = _ref.id,
      _ref$values = _ref.values,
      values = _ref$values === void 0 ? {} : _ref$values;

  var _useTranslation = useTranslation(),
      t = _useTranslation.t;

  var translation = t(id);
  var children = React.useMemo(function () {
    return Object.entries(values).reduce(function (components, _ref2) {
      var _ref3 = _slicedToArray(_ref2, 2),
          key = _ref3[0],
          value = _ref3[1];

      var placeholder = "{".concat(key, "}");
      var index = components.findIndex(function (component) {
        return typeof component === 'string' && component.includes(placeholder);
      });

      if (index >= 0 && /*#__PURE__*/React.isValidElement(value)) {
        var _split = components[index].split(placeholder),
            _split2 = _slicedToArray(_split, 2),
            left = _split2[0],
            right = _split2[1];

        components.splice(index, 1, left, /*#__PURE__*/React.cloneElement(value, {
          key: key
        }), right);
      }

      return components;
    }, [translation]);
  }, [translation]);
  return /*#__PURE__*/React.createElement(React.Fragment, {}, children);
};

exports.I18nProvider = I18nProvider;
exports.Translation = Translation;
exports.useTranslation = useTranslation;
